/*
 * helpers.h - various helpers for cve-check-tool
 *
 * Copyright (C) 2021 Aleksei Nikiforov <darktemplar@basealt.ru>
 *
 * cve-check-tool is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 */

#pragma once

#include <memory>
#include <stdexcept>
#include <string>

#include <boost/property_tree/ptree.hpp>
#include <clickhouse-cpp/client.h>

bool is_valid_table_name(const std::string &value);

template <typename T>
bool always_true(const T &)
{
    return true;
}

template <typename T>
void optional_set(T &value, const boost::property_tree::ptree &tree, const char *element_name, bool (*check_function)(const T &))
{
    auto element = tree.get_child_optional(element_name);
    if (element)
    {
        if (check_function(element->get_value<T>()))
        {
            value = element->get_value<T>();
        }
        else
        {
            throw std::runtime_error(std::string("Invalid value for option '") + std::string(element_name) + std::string("'"));
        }
    }
}

template <typename T>
void optional_set(T &value, const boost::property_tree::ptree &tree, const char *element_name)
{
    optional_set(value, tree, element_name, &always_true<T>);
}

template <typename T>
std::shared_ptr<T> ensure_not_null(const std::shared_ptr<T> &value)
{
    if (!value)
    {
        throw std::runtime_error("Invalid pointer cast");
    }

    return value;
}

std::string sv_to_string( std::string_view s );

void fill_connection_options(const boost::property_tree::ptree &connection_section, clickhouse::ClientOptions &client_options);

std::string vulnerabilities_table_creation_command(const std::string &table_name);

std::string vulnerabilities_status_table_creation_command(const std::string &table_name);

std::string absent_packages_table_creation_command(const std::string &table_name);

std::string cpe_dictionary_table_creation_command(const std::string &table_name);

std::string cpe_dictionary_match_table_creation_command(const std::string &table_name);
