/*
 * util.h - cve-check-tool
 *
 * Copyright (C) 2015 Intel Corporation
 *
 * cve-check-tool is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 */

#pragma once

#include <time.h>

#include <string>
#include <vector>

/**
 * Convert date into unix seconds
 *
 * @param date input
 * @return int64_t unix timestamp, or -1 if it doesn't parse
 */
time_t parse_date(const std::string &date);

/**
 * Determine if the given path exists on disk
 *
 * @param p Path for the file to test
 * @return a boolean value, true if the condition is met
 */
bool cve_file_exists(const std::string &p);

/**
 * Determine if the given path exists, and is a directory
 *
 * @param p Path to the directory
 * @return a boolean value, true if the condition is met
 */
bool cve_is_dir(const std::string &p);

/**
 * Return the parent path for a given file
 *
 * @param p Path to file
 * @return a newly allocated string
 */
std::string cve_get_file_parent(const std::string &p);

/**
 * Return absolute path to the dot file in format .basename(db_path).suffix
 *
 * @param db_path Path to the database file
 * @param suffix Suffix of the database file
 * @return a newly allocated string or NULL in case of error
 */
std::string make_db_dot_fname(const std::string &db_path, const std::string &suffix);

std::string nvdcve_make_fname(int year, const std::string &fext);

void split_cpe(const std::string &cpe, std::vector<std::string> &result);
